@@ -8,10 +8,13 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
+from typing import Optional
+
+from pip_services3_commons.config import IConfigurable, ConfigParams
 
-from pip_services3_commons.config import IConfigurable
-from .MemoryPersistence import MemoryPersistence
 from .JsonFilePersister import JsonFilePersister
+from .MemoryPersistence import MemoryPersistence
+
 
 class FilePersistence(MemoryPersistence, IConfigurable):
     """
@@ -21,29 +24,30 @@ class FilePersistence(MemoryPersistence, IConfigurable):
     This is the most basic persistence component that is only
     able to store data items of any type. Specific CRUD operations
     over the data items must be implemented in child classes by
-    accessing this._items property and calling [[save]] method.
+    accessing self._items property and calling :func:save method.
 
     ### Configuration parameters ###
-
         - path:                path to the file where data is stored
 
     ### References ###
-        - *:logger:*:*:1.0   (optional) ILogger components
-                              to pass log messages
+        - `*:logger:*:*:1.0`   (optional) ILogger components to pass log messages
 
     Example:
-        class MyJsonFilePersistence(FilePersistence):
-            def __init__(self, path):
-                super(MyJsonFilePersistence, self).__init__(JsonPersister(path))
 
-            def get_by_name(self, correlationId, name):
-                item = self.find(name)
-                ...
-                return item
+    .. code-block:: python
+
+       class MyJsonFilePersistence(FilePersistence):
+           def __init__(self, path):
+               super(MyJsonFilePersistence, self).__init__(JsonPersister(path))
+
+           def get_by_name(self, correlationId, name):
+               item = self.find(name)
+               ...
+               return item
     """
-    _persister = None
+    _persister: JsonFilePersister = None
 
-    def __init__(self, persister):
+    def __init__(self, persister: Optional[JsonFilePersister] = None):
         """
         Creates a new instance of the persistence.
 
@@ -56,7 +60,7 @@ class FilePersistence(MemoryPersistence, IConfigurable):
         # self._saver = self._persister
         # self._loader = self._persister
 
-    def configure(self, config):
+    def configure(self, config: ConfigParams):
         """
         Configures component by passing configuration parameters.
 
